import pyfie
import matplotlib.pyplot as plt

# 利便のため PyFIE 関数が返すエラーコードに応じて例外を発生させる機能を有効化
pyfie.ctrl.enable_f_err_exception(True)

# 処理対象画像の読み込み
image = pyfie.imread("edge1d_line_peaks_src.png")

# スキャンライン（1次元エッジ検出とピーク探索を行う範囲）を設定
scanline = pyfie.DSGMT_T((50, 50), (200, 200))

# 1次元エッジ検出用のデータ受け取り用変数を用意
MAX_EDGES = 10000
num_edges = pyfie.INT(MAX_EDGES)
edges = pyfie.F_DEDGE.ARRAY(num_edges)

# 1次元エッジ検出(接頭辞を省略したPyFIE関数使用)
pyfie.edge1d_line(
    image,  # 入力画像
    scanline,  # 計測ライン
    prj_width=3,  # 検出片幅
    filter_mode=pyfie.F_EDGE1D_DOG,  # エッジ抽出フィルタ
    direct_mode=pyfie.F_DTC_BOTH,  # 検出するエッジ方向
    diff_type=pyfie.F_RELATIVE_THR,  # 濃度差しきい値の種別
    diff_thr=25,  # エッジの最小濃度差しきい値
    sort_mode=pyfie.F_POS_SORT,  # 検出されたエッジの保存順
    edges=edges,  # 検出されたエッジ点保存配列のポインタ
    edge_num=num_edges  # 検出されたエッジ点個数
)

# 取得したエッジを表示
print("num edges:", num_edges)
for i, edge in enumerate(edges[:num_edges]):
    print("#{}: x = {:.2f}, y = {:.2f}, mag = {:.2f}".format(
        i, edge.x, edge.y, edge.mag
    ))

# 画像オブジェクトのプロット
image.imshow()
# 取得したエッジをプロット
scanline.plot(lw=1, color="blue")
edges.plot(num=num_edges, c="red", s=200, marker="+", zorder=4)
# 結果をプロットした画像の保存
plt.savefig("edge1d_line_result.png")
# 結果をプロットした画像の表示
pyfie.plot_show()
